API Reference
=============

This section discusses the API offered by this package to interact with `Deep Intelligence <https://deepint.net/>`_.

.. toctree::
   :maxdepth: 5

   ../_api/auth.rst
   ../_api/core.rst
   ../_api/error.rst